#!/bin/bash

# ***************************************************************************
# *                         WARRANTY DISCLAIMER
# ***************************************************************************
# * THE SAMPLE SCRIPT IS BEING PROVIDED TO YOU "AS IS".  DELL DISCLAIMS ANY
# * AND ALL WARRANTIES, EXPRESS, IMPLIED OR STATUTORY, WITH RESPECT TO THE
# * SAMPLE SCRIPT, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
# * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, TITLE AND ANY WARRANTY
# * OF NON-INFRINGEMENT. YOU WILL USE THE SAMPLE SCRIPT AT YOUR OWN RISK.
# * DELL SHALL NOT BE LIABLE TO YOU FOR ANY DIRECT OR INDIRECT DAMAGES
# * INCURRED IN USING THE SAMPLE SCRIPT. IN NO EVENT SHALL DELL OR ITS
# * SUPPLIERS BE RESPONSIBLE FOR ANY DIRECT OR INDIRECT DAMAGES WHATSOEVER
# * (INCLUDING, WITHOUT LIMITATION, DAMAGES FOR LOSS OF PROFITS, LOSS OF USE,
# * LOSS OF DATA, BUSINESS INTERRUPTION, OR OTHER PECUNIARY LOSS, NOR FOR
# * PUNITIVE, INCIDENTAL, CONSEQUENTIAL, OR SPECIAL DAMAGES OF ANY KIND,
# * UNDER ANY PART OF THIS AGREEMENT, EVEN IF ADVISED OR AWARE OF THE
# * POSSIBILITY OF SUCH DAMAGES).
# ***************************************************************************

# ***************************************************************************
# * Script Name: raccap.sh
# *
# * Purpose:
# *   This script captures the RAC settings to a file.
# *
# * Layout: 
# *   This script is divided into the following sections for ease of use and
# *   extensibility:
# *     Section 1: Set Paths for Deployment Toolkit Tools and Scripts
# *     Section 2: Ask User's Input, Input Verification, and Code Execution
# *
# * Tools Used: 
# *   racadm to capture the system settings
# *
# * External Dependencies
# *   DT_TOOLS, DT_SYSTEMS set by tkenvset.sh let task scripts
# *   know where they can find Toolkit Tools and Configuration scripts.
# *   DT_PLATFORM is set by tkenvset.sh using Platform Discovery.
# *
# * Input Parameters
# *	  $1 This is the filename to capture the Settings into.
# *
# * !!! WARNING !!!
# * If the file into which information needs to be captured exists it will be 
# * deleted.
# *
# ***************************************************************************

# Print usage if script is not called with correct number of arguments
noarg ()
{
	echo "usage: raccap <filename>"
	echo Filename is the name of the file to capture the Settings into.
	exit 2
}

# ***************************************************************************
# * Function to display the outcome (Success or Failure and Error Handling)
# * Expects $? as an argument to display the Return/Error Code.
# ***************************************************************************
toolfail ()
{
	echo racadm failed with error code $1.
	$DT_SCRIPTS/errhndl.sh $0 32
	# Exit the script if Return Value is 2
	if [ $? -eq 2 ]; then
		echo "Exiting."
		exit
	fi
}

comment_lines ()
{
	#first delete blank lines
	sed '/^$/d' $DT_RAC_CAPFILE >/tmp/backup.file
	mv -f /tmp/backup.file $DT_RAC_CAPFILE

	sed 's/^syssvctag/\;syssvctag/g' $DT_RAC_CAPFILE > /tmp/backup.file
	mv -f /tmp/backup.file $DT_RAC_CAPFILE

	sed 's/^svctag/\;svctag/g' $DT_RAC_CAPFILE > /tmp/backup.file
	mv -f /tmp/backup.file $DT_RAC_CAPFILE

	sed 's/^ipaddress/\;ipaddress/g' $DT_RAC_CAPFILE >/tmp/backup.file
	mv -f /tmp/backup.file $DT_RAC_CAPFILE

	#comment out lines based on the output of some dependent option so that
	#unnecessary warning are not generated when you do racrep on this file
	#on a 9g server.

	syscfg_output=`$DT_TOOLS/syscfg lcp --ipaddrsrc --dnsdhcp --domainnamednsdhcp`
	echo $syscfg_output | grep "ipaddrsrc=dhcp" >/dev/null
	if [ $? -eq 0 ]; then
		sed 's/^gateway=/\;gateway=/g' $DT_RAC_CAPFILE >/tmp/backup.file
		sed 's/^subnetmask=/\;subnetmask=/g' /tmp/backup.file > $DT_RAC_CAPFILE
	fi
	echo $syscfg_output | grep "dnsdhcp=enable" >/dev/null
	if [ $? -eq 0 ]; then
		sed 's/^dnsserver1=/\;dnsserver1=/g' $DT_RAC_CAPFILE >/tmp/backup.file
		sed 's/^dnsserver2=/\;dnsserver2=/g' /tmp/backup.file > $DT_RAC_CAPFILE
	fi
	echo $syscfg_output | grep "domainnamednsdhcp=enable" >/dev/null
	if [ $? -eq 0 ]; then
		sed 's/^domainname=/\;domainname=/g' $DT_RAC_CAPFILE >/tmp/backup.file
		mv -f /tmp/backup.file $DT_RAC_CAPFILE
	fi
}


do_idrac_cap ()
{
	> $DT_RAC_CAPFILE
	echo '[syscfg]' > $DT_RAC_CAPFILE

	#Now idrac is available on modular as well as monolithic. On monolithic syssvctag 
	#is not supported, it has to be svctag. JM - 11/27/2008
    	test=""
	test=`syscfg | grep slot`
	if [ -n "$test" ]; then
		$DT_TOOLS/syscfg --sysname --sysid --biosver --syssvctag >>$DT_RAC_CAPFILE
	else
		$DT_TOOLS/syscfg --sysname --sysid --biosver --svctag >>$DT_RAC_CAPFILE
	fi

	echo ";Do not edit anything above this line" >>$DT_RAC_CAPFILE
	$DT_TOOLS/syscfg lcp --ipaddrsrc --gateway --ipaddress --subnetmask \
		--dnsdhcp --domainnamednsdhcp --dnsserver1 --dnsserver2 --dnsracname \
		--dnsregisterrac --domainname >>$DT_RAC_CAPFILE
	retval=$?
	comment_lines
}
do_rac5_cap ()
{
	> $DT_RAC_CAPFILE
	echo '[syscfg]' > $DT_RAC_CAPFILE
	$DT_TOOLS/syscfg --sysname --sysid --biosver --svctag >>$DT_RAC_CAPFILE
	echo ";Do not edit anything above this line" >>$DT_RAC_CAPFILE
	$DT_TOOLS/syscfg lcp --ipaddrsrc --gateway --ipaddress --subnetmask --nicselection \
		--autoneg --dnsdhcp --domainnamednsdhcp --dnsserver1 --dnsserver2 --dnsracname \
		--dnsregisterrac --domainname --fullduplex --speed >>$DT_RAC_CAPFILE
	retval=$?
	comment_lines
}

# **************************************************************************
# * Functions checks the version of remote access controller on the server
# * sets the variable racversion=3/4/5/idrac.
# **************************************************************************
check_rac_ver()
{
    rac3=1028:0008
	rac4=1028:0012
    test=""
	test=`lspci -i $DT_TOOLS/pci.ids -d $rac3`
	if [ -n "$test" ]; then
		racversion="3"
	fi
    test=""
	test=`lspci -i $DT_TOOLS/pci.ids -d $rac4`
	if [ -n "$test" ]; then
		racversion="4"
	fi
    test=""
	test=`syscfg | grep racreset`
	if [ -n "$test" ]; then
		racversion="5"
	fi
    test=""
	test=`syscfg | grep idracversion`
	if [ -n "$test" ]; then
		racversion="idrac"
	fi
}

# ***************************************************************************
# * Section 1: Set Paths for Deployment Toolkit Tools and Scripts
# ***************************************************************************

# check for proper usage of the script 
if [ -z $1 ]; then
	noarg
fi

if [ -z $DT_TOOLS ]; then
	. tkenvset.sh
fi

# Check the version of the rac on the system.
racversion="0"
check_rac_ver

if [ $racversion = "0" ]; then
	#Nothing to do if we find no RAC on the system.
	$DT_SCRIPTS/errhndl.sh $0 34
	exit 0;
fi
# #############################################################################
#                          USER MODIFICATION REQUIRED
# Below are the user defined variables that this script uses.
# In a full deployment, these variables should be customized to fit the 
# user's needs.
# #############################################################################
[ -z "$DT_RAC_CAPFILE" ] &&	DT_RAC_CAPFILE=$DT_SYSTEMS/$DT_PLATFORM/raccfg.ini 

# ***************************************************************************
# * Section 2: Ask User's Input, Input Verification, and Code Execution
# ***************************************************************************
[ ! -z "$1" ] && DT_RAC_CAPFILE=$1

if [ -e $DT_RAC_CAPFILE ]; then
	rm -f $DT_RAC_CAPFILE
fi

if [ $racversion = "5" ]; then
	do_rac5_cap
elif [ $racversion = "idrac" ]; then
        do_idrac_cap
else
	$DT_TOOLS/racadm getconfig -f $DT_RAC_CAPFILE
	retval=$?
fi
if [ $retval -ne 0 ]; then
	toolfail $retval
fi
