#!/bin/bash

# ***************************************************************************
# *                         WARRANTY DISCLAIMER
# ***************************************************************************
# * THE SAMPLE SCRIPT IS BEING PROVIDED TO YOU "AS IS".  DELL DISCLAIMS ANY
# * AND ALL WARRANTIES, EXPRESS, IMPLIED OR STATUTORY, WITH RESPECT TO THE
# * SAMPLE SCRIPT, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
# * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, TITLE AND ANY WARRANTY
# * OF NON-INFRINGEMENT. YOU WILL USE THE SAMPLE SCRIPT AT YOUR OWN RISK.
# * DELL SHALL NOT BE LIABLE TO YOU FOR ANY DIRECT OR INDIRECT DAMAGES
# * INCURRED IN USING THE SAMPLE SCRIPT. IN NO EVENT SHALL DELL OR ITS
# * SUPPLIERS BE RESPONSIBLE FOR ANY DIRECT OR INDIRECT DAMAGES WHATSOEVER
# * (INCLUDING, WITHOUT LIMITATION, DAMAGES FOR LOSS OF PROFITS, LOSS OF USE,
# * LOSS OF DATA, BUSINESS INTERRUPTION, OR OTHER PECUNIARY LOSS, NOR FOR
# * PUNITIVE, INCIDENTAL, CONSEQUENTIAL, OR SPECIAL DAMAGES OF ANY KIND,
# * UNDER ANY PART OF THIS AGREEMENT, EVEN IF ADVISED OR AWARE OF THE
# * POSSIBILITY OF SUCH DAMAGES).
# ***************************************************************************

# ***************************************************************************
# * Name: sysrep.sh
# *
# * Purpose: 
# *   This script applies (or replicates) the BIOS and BMC settings saved in a 
# * file to the current system.
# *
# * Layout: 
# *   This script is divided into the following sections for ease of use and
# *   extensibility:
# *     Section 1: Set Paths for Deployment Toolkit Tools and Scripts
# *     Section 2: Ask User's Input, Input Verification, and Code Execution
# *
# * Tools Used: 
# *   syscfg to configure BIOS and BMC settings
# *   Check the CLI Reference Guide for more syscfg options
# *
# * External Dependencies
# *   DT_TOOLS, DT_SYSTEMS set by tkenvset.sh let task scripts
# *   know where they can find Toolkit Tools and Configuration scripts.
# *   DT_PLATFORM is set by tkenvset.sh using Platform Discovery
# *
# * Input Parameters
# *	  $1 This is the filename containing the captured Settings.
# *	  $2 Is the filename to log the replication details into.
# *	
# *	Note: These two parameters can be set in this file manually as well.
# *
# * GLOBAL WARNING
# *   This script updates the activity/error log and requires write access to
# *   the file defined by DT_SYS_LOGFILE=
# *
# *   This script updates the BIOS and BMC Settings and needs a System Reboot 
# *   for the changes to take effect
# *
# *   If the script detects a change in the memory redundancy configuration,
# *   the system needs an extra reboot and the scripts needs to be executed
# *   again for the replication to complete successfully.
# *
# ***************************************************************************

# Print usage if script is not called with correct number of arguments
noarg ()
{
        echo "usage: sysrep <filename>"
	echo Filename is the name of the file to capture the Settings into.
        exit 2
}

# ***************************************************************************
# * Function to display the outcome (Success or Failure and Error Handling)
# * Expects $? as an argument to display the Return/Error Code.
# ***************************************************************************
toolfail ()
{
	echo syscfg failed with error code $1.
	$DT_SCRIPTS/errhndl.sh $0 32
	# Exit the script if Return Value is 2
	if [ $? -eq 2 ]; then
		echo "Exiting."
		exit $retsyscfg 
	fi
}

# ***************************************************************************
# * Section 1: Set Paths for Deployment Toolkit Tools and Scripts
# ***************************************************************************
# check for proper usage of the script
if [ -z $1 ]; then
        noarg
fi

if [ -z $DT_TOOLS ]; then
	. tkenvset.sh
fi

# #############################################################################
#                          USER MODIFICATION REQUIRED
# Below are the user defined variables that this script uses.
# In a full deployment, these variables should be customized to fit the 
# user's needs.
# #############################################################################
[ -z "$DT_SYS_REPFILE" ] &&	DT_SYS_REPFILE=$DT_SYSTEMS/$DT_PLATFORM/syscfg.ini

# Path and filename where log file is to be created, for ex: F:\log.txt
# Note:  The path must exist and the media must be writeable.
DT_SYS_LOGFILE=

# ***************************************************************************
# * Section 2: Ask User's Input, Input Verification, and Code Execution
# ***************************************************************************

# Name of the file from which to replicate System Configuration settings.
[ ! -z $1 ] && DT_SYS_REPFILE=$1

# Path and filename where log file is to be created, for ex: F:\log.txt
# Note:  The path must exist and the media must be writeable.
[ ! -z $2 ] && DT_SYS_LOGFILE=$2

# Input Verification
if [ -z "$DT_SYS_LOGFILE" ]; then
	$DT_SCRIPTS/errhndl.sh $0 01
fi
if [ -z "$DT_SYS_REPFILE" ]; then
	$DT_SCRIPTS/errhndl.sh $0 24
fi
if [ ! -e $DT_SYS_REPFILE ]; then
	$DT_SCRIPTS/errhndl.sh $0 53
	exit
fi;

DT_TEMP=`$DT_TOOLS/syscfg --redmem`
DT_MEM_BEFORE=`echo $DT_TEMP | cut -d = -f2`

DT_SYS_LOGFILE_OPT=
if [ ! -z "$DT_SYS_LOGFILE" ]; then
	DT_SYS_LOGFILE_OPT="-l $DT_SYS_LOGFILE"
fi;
$DT_TOOLS/syscfg -i $DT_SYS_REPFILE $DT_SYS_LOGFILE_OPT
retval=$?
retsyscfg=$retval
if [ $retval -ne 0 ]; then
	toolfail $retval
fi;

DT_TEMP=`$DT_TOOLS/syscfg --redmem`
DT_MEM_AFTER=`echo $DT_TEMP | cut -d = -f2`

if [ "$DT_MEM_BEFORE" != "$DT_MEM_AFTER" ]; then
	echo !!!!! WARNING !!!!!
	echo A change in the redundant memory mode is detected.
	echo You should reboot the system and rerun this script for replication to complete.
	echo If not the system settings will not be replicated.
else
	echo System settings successfully replicated from $DT_SYS_REPFILE
	if [ ! -z "$DT_SYS_LOGFILE" ]; then
		echo Details are logged in $DT_SYS_LOGFILE
	fi;
fi;

